@@ -47,6 +47,7 @@
 
 SCH_MOVE_TOOL::SCH_MOVE_TOOL() :
         EE_TOOL_BASE<SCH_EDIT_FRAME>( "eeschema.InteractiveMove" ),
+        m_inMoveTool( false ),
         m_moveInProgress( false ),
         m_isDrag( false ),
         m_moveOffset( 0, 0 )
@@ -126,6 +127,11 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
         return 0;
     }
 
+    if( m_inMoveTool )      // Must come after m_moveInProgress checks above...
+        return 0;
+
+    REENTRANCY_GUARD guard( &m_inMoveTool );
+
     // Be sure that there is at least one item that we can move. If there's no selection try
     // looking for the stuff under mouse cursor (i.e. Kicad old-style hover selection).
     EE_SELECTION& selection = m_selectionTool->RequestSelection( EE_COLLECTOR::MovableItems );
@@ -438,6 +444,14 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
             chain_commands = true;
             break;
         }
+        else if( evt->IsAction( &EE_ACTIONS::rotateCW ) )
+        {
+            m_toolMgr->RunAction( EE_ACTIONS::rotateCW, true );
+        }
+        else if( evt->IsAction( &EE_ACTIONS::rotateCCW ) )
+        {
+            m_toolMgr->RunAction( EE_ACTIONS::rotateCCW, true );
+        }
         else if( evt->Action() == TA_CHOICE_MENU_CHOICE )
         {
             if( evt->GetCommandId().get() >= ID_POPUP_SCH_SELECT_UNIT_CMP
@@ -544,6 +558,7 @@ void SCH_MOVE_TOOL::getConnectedDragItems( SCH_ITEM* aOriginalItem, const wxPoin
     EE_RTREE&         items = m_frame->GetScreen()->Items();
     EE_RTREE::EE_TYPE itemsOverlapping = items.Overlapping( aOriginalItem->GetBoundingBox() );
     bool              ptHasUnselectedJunction = false;
+    SCH_LINE*         newWire = nullptr;
 
     for( SCH_ITEM* item : itemsOverlapping )
     {
@@ -625,19 +640,19 @@ void SCH_MOVE_TOOL::getConnectedDragItems( SCH_ITEM* aOriginalItem, const wxPoin
         case SCH_SHEET_T:
         case SCH_SYMBOL_T:
         case SCH_JUNCTION_T:
-            if( test->IsConnected( aPoint ) )
+            if( test->IsConnected( aPoint ) && !newWire )
             {
                 // Add a new wire between the symbol or junction and the selected item so
                 // the selected item can be dragged.
-                SCH_LINE* newWire = nullptr;
-
-                if( test->GetLayer() == LAYER_BUS_JUNCTION ||
-                    aOriginalItem->GetLayer() == LAYER_BUS )
+                if( test->GetLayer() == LAYER_BUS_JUNCTION
+                        || aOriginalItem->GetLayer() == LAYER_BUS )
                 {
                     newWire = new SCH_LINE( aPoint, LAYER_BUS );
                 }
                 else
+                {
                     newWire = new SCH_LINE( aPoint, LAYER_WIRE );
+                }
 
                 newWire->SetFlags( IS_NEW );
                 m_frame->AddToScreen( newWire, m_frame->GetScreen() );
@@ -685,6 +700,26 @@ void SCH_MOVE_TOOL::getConnectedDragItems( SCH_ITEM* aOriginalItem, const wxPoin
                     }
                 }
             }
+            else if( test->IsConnected( aPoint ) && !newWire )
+            {
+                // Add a new wire between the label and the selected item so the selected item
+                // can be dragged.
+                if( test->GetLayer() == LAYER_BUS_JUNCTION
+                        || aOriginalItem->GetLayer() == LAYER_BUS )
+                {
+                    newWire = new SCH_LINE( aPoint, LAYER_BUS );
+                }
+                else
+                {
+                    newWire = new SCH_LINE( aPoint, LAYER_WIRE );
+                }
+
+                newWire->SetFlags( IS_NEW );
+                m_frame->AddToScreen( newWire, m_frame->GetScreen() );
+
+                newWire->SetFlags( TEMP_SELECTED | STARTPOINT );
+                aList.push_back( newWire );
+            }
 
             break;
 
