@@ -165,8 +165,11 @@ void BOARD_COMMIT::Push( const wxString& aMessage, bool aCreateUndoEntry, bool a
         {
             case CHT_ADD:
             {
-                if( selTool->GetEnteredGroup() && !boardItem->GetParentGroup() )
+                if( selTool && selTool->GetEnteredGroup() && !boardItem->GetParentGroup()
+                        && PCB_GROUP::IsGroupableType( boardItem->Type() ) )
+                {
                     selTool->GetEnteredGroup()->AddItem( boardItem );
+                }
 
                 if( m_isFootprintEditor )
                 {
