@@ -1,7 +1,7 @@
 /*
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
- * Copyright (C) 1992-2021 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2022 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,6 +48,7 @@
 #include <settings/settings_manager.h>
 #include <footprint_editor_settings.h>
 #include "footprint_viewer_frame.h"
+#include "tools/pad_tool.h"
 #include <wx/choicdlg.h>
 #include <wx/filedlg.h>
 
@@ -101,7 +102,7 @@ static wxFileName getFootprintFilenameFromUser( wxWindow* aParent, const wxStrin
  * Read a file to detect the type.
  * @param aFile - open file to be read. File pointer will be closed.
  * @param aFileName - file name to be read
- * @param aName - wxString to receive the footprint name iff type is LEGACY
+ * @param aName - wxString to receive the footprint name if type is LEGACY
  */
 static IO_MGR::PCB_FILE_T detect_file_type( FILE* aFile, const wxFileName& aFileName,
                                             wxString* aName )
@@ -257,7 +258,7 @@ FOOTPRINT* FOOTPRINT_EDIT_FRAME::ImportFootprint( const wxString& aName )
         return nullptr;
     }
 
-    cfg->m_LastImportExportPath = lastOpenedPathForLoading;
+    m_mruPath = cfg->m_LastImportExportPath = fn.GetPath();
 
     wxString footprintName;
     IO_MGR::PCB_FILE_T fileType = detect_file_type( fp, fn.GetFullPath(), &footprintName );
@@ -784,6 +785,11 @@ bool FOOTPRINT_EDIT_FRAME::SaveFootprint( FOOTPRINT* aFootprint )
     if( !aFootprint )      // Happen if no footprint loaded
         return false;
 
+    PAD_TOOL* padTool = m_toolManager->GetTool<PAD_TOOL>();
+
+    if( padTool->InPadEditMode() )
+        m_toolManager->RunAction( PCB_ACTIONS::recombinePad, true );
+
     wxString libraryName = aFootprint->GetFPID().GetLibNickname();
     wxString footprintName = aFootprint->GetFPID().GetLibItemName();
     bool     nameChanged = m_footprintNameWhenLoaded != footprintName;
@@ -879,7 +885,6 @@ bool FOOTPRINT_EDIT_FRAME::SaveFootprintToBoard( bool aAddNew )
         return false;
     }
 
-    TOOL_MANAGER*   toolMgr = pcbframe->GetToolManager();
     BOARD*     mainpcb  = pcbframe->GetBoard();
     FOOTPRINT* sourceFootprint  = nullptr;
     FOOTPRINT* editorFootprint = GetBoard()->GetFirstFootprint();
@@ -906,14 +911,16 @@ bool FOOTPRINT_EDIT_FRAME::SaveFootprintToBoard( bool aAddNew )
         return false;
     }
 
-    if( aAddNew && toolMgr->GetTool<BOARD_EDITOR_CONTROL>()->PlacingFootprint() )
+    TOOL_MANAGER* pcb_ToolManager = pcbframe ? pcbframe->GetToolManager() : nullptr;
+
+    if( aAddNew && pcb_ToolManager
+            && pcb_ToolManager->GetTool<BOARD_EDITOR_CONTROL>()->PlacingFootprint() )
     {
         DisplayError( this, _( "Previous footprint placement still in progress." ) );
         return false;
     }
 
     m_toolManager->RunAction( PCB_ACTIONS::selectionClear, true );
-    toolMgr->RunAction( PCB_ACTIONS::selectionClear, true );
     BOARD_COMMIT commit( pcbframe );
 
     // Create a copy for the board, first using Clone() to keep existing Uuids, and then either
@@ -960,7 +967,7 @@ bool FOOTPRINT_EDIT_FRAME::SaveFootprintToBoard( bool aAddNew )
         commit.Push( wxT( "Insert footprint" ) );
 
         pcbframe->Raise();
-        toolMgr->RunAction( PCB_ACTIONS::placeFootprint, true, newFootprint );
+        pcb_ToolManager->RunAction( PCB_ACTIONS::placeFootprint, true, newFootprint );
     }
 
     newFootprint->ClearFlags();
@@ -1175,9 +1182,6 @@ FOOTPRINT* PCB_BASE_FRAME::CreateNewFootprint( const wxString& aFootprintName, b
     // Creates the new footprint and add it to the head of the linked list of footprints
     FOOTPRINT* footprint = new FOOTPRINT( GetBoard() );
 
-    // Update parameters: timestamp ...
-    footprint->SetLastEditTime();
-
     // Update its name in lib
     footprint->SetFPID( LIB_ID( wxEmptyString, footprintName ) );
 
